@@ -991,6 +991,88 @@ class QuestionBank(Base):
         return f'{self.title}'
 
 
+class Question(Base):
+    """
+    Вопрос
+    """
+    __tablename__ = 'assessment_questions'
+
+    # Идентификатор
+    id = Column(Integer, primary_key=True)
+
+    # Наименование
+    name = Column(String(255))
+
+    # Данные вопроса
+    # В формате YAML
+    question_data = Column(String)
+
+    # Идентификатор контекста
+    context_id = Column(Integer)
+
+    # Тип контекста
+    context_type = Column(String(255))
+
+    # Статус
+    # Возможные значения:
+    # - active (Активный)
+    # - deleted (Удален)
+    workflow_state = Column(String(255))
+
+    @validates('workflow_state')
+    def validate_workflow_state(self, key, value):
+        """
+        Значением workflow_state может быть следующие значения:
+        - active (Активный)
+        - deleted (Удален)
+        """
+        assert value in ['active', 'deleted']
+        return value
+
+    # Дата и время создания
+    # server_default - Автоматически устанавливает значение created_at на текущую дату и время при создании
+    created_at = Column(DateTime, server_default=func.now())
+
+    # Дата и время изменения
+    # onupdate - Автоматически изменяет updated_at на текущую дату и время
+    updated_at = Column(DateTime, onupdate=func.now())
+
+    # Банк вопросов
+    question_bank_id = Column(
+        'assessment_question_bank_id', ForeignKey('assessment_question_banks.id'))
+    question_bank = relationship('QuestionBank')
+
+    # Дата и время удаления
+    # Обязательно, если workflow_state="deleted"
+    deleted_at = Column(DateTime)
+
+    @validates('deleted_at')
+    def validate_deleted_at(self, key, value):
+        if self.workflow_state == 'deleted':
+            assert value is not None
+
+        return value
+
+    # Неизвестное поле
+    migration_id = Column(String(255))
+
+    # Позиция в банке вопросов
+    # Определяет в каком позиции находится данный вопрос в списке вопросов внутри банка вопросов
+    # Чем меньше значение, тем выше он находится
+    # Не должен совпадать с значениями другим вопросов в пределах банка вопросов
+    position = Column(Integer)
+
+    # Корневая учетная запись
+    root_account_id = Column(ForeignKey('accounts.id'))
+    root_account = relationship('Account')
+
+    def __repr__(self):
+        return f'<Question {self} (id={self.id} question_bank_id={self.question_bank_id} workflow_state={self.workflow_state})>'
+
+    def __str__(self):
+        return f'{self.name}'
+
+
 class Override(Base):
     """
     Модель "Назначение"
